==> react-date-primitives-0.4.1.tgz: package/esm/components/CalendarMonth.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import * as React from 'react';
import { startOfMonth, isDayAfter, isDayBefore, isSameDay, setMonth, getDatesofMonth } from './utils';
/**
 * Primitive react component that can be used to make a datepicker.
 */
var CalendarMonth = /** @class */ (function (_super) {
    __extends(CalendarMonth, _super);
    function CalendarMonth() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.getDropdowns = function (props) {
            var minDate = props.minDate, maxDate = props.maxDate, month = props.month;
            var firstDay = startOfMonth(month);
            var today = new Date();
            var minYear = minDate ? minDate.getFullYear() : today.getFullYear() - 50;
            var maxYear = maxDate ? maxDate.getFullYear() + 1 : today.getFullYear() + 5;
            var dropdownMonths = Array.from({ length: 12 }, function (_, i) { return ({
                disabled: Boolean((minDate && isDayBefore(setMonth(month, i), minDate)) ||
                    (maxDate && isDayAfter(setMonth(month, i), maxDate))),
                value: i,
                selected: firstDay.getMonth() === i
            }); });
            var dropdownYears = Array.from({ length: maxYear - minYear }, function (_, i) { return ({
                value: i + minYear,
                disabled: false,
                selected: i + minYear === firstDay.getFullYear()
            }); });
            return [dropdownMonths, dropdownYears];
        };
        return _this;
    }
    CalendarMonth.prototype.getDaysofMonth = function (props) {
        var month = props.month, startDate = props.startDate, endDate = props.endDate, minDate = props.minDate, maxDate = props.maxDate;
        var currentMonth = getDatesofMonth(month);
        var startDateDisabled = !!startDate && !!minDate && !isDayAfter(startDate, minDate);
        return currentMonth.map(function (week) {
            return week.map(function (day) {
                var date = day.date, inCurrentMonth = day.inCurrentMonth;
                var disabled = !inCurrentMonth ||
                    Boolean((minDate && isDayBefore(date, minDate)) ||
                        (maxDate && isDayAfter(date, maxDate)));
                return {
                    date: date,
                    inRange: inCurrentMonth &&
                        !startDateDisabled &&
                        !disabled &&
                        Boolean(startDate &&
                            isDayAfter(date, startDate) &&
                            endDate &&
                            isDayBefore(date, endDate)),
                    selected: !disabled &&
                        Boolean((startDate && isSameDay(date, startDate)) ||
                            (endDate && isSameDay(date, endDate))),
                    disabled: disabled,
                    inCurrentMonth: inCurrentMonth
                };
            });
        });
    };
    CalendarMonth.prototype.render = function () {
        var _a;
        var _b = this.props, month = _b.month, render = _b.render, showDropdowns = _b.showDropdowns;
        var monthsDropdown;
        var yearsDropdown;
        if (showDropdowns) {
            _a = this.getDropdowns(this.props), monthsDropdown = _a[0], yearsDropdown = _a[1];
        }
        return render({
            days: this.getDaysofMonth(this.props),
            month: startOfMonth(month),
            monthsDropdown: monthsDropdown,
            yearsDropdown: yearsDropdown
        });
    };
    return CalendarMonth;
}(React.Component));
export { CalendarMonth };

==> react-date-primitives-0.5.0.tgz: package/esm/components/CalendarMonth.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import * as React from 'react';
import { startOfMonth, isDayAfter, isDayBefore, isSameDay, setMonth, getDatesofMonth } from './utils';
/**
 * Primitive react component that can be used to make a datepicker.
 */
var CalendarMonth = /** @class */ (function (_super) {
    __extends(CalendarMonth, _super);
    function CalendarMonth() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.getDropdowns = function (props) {
            var minDate = props.minDate, maxDate = props.maxDate, month = props.month;
            var firstDay = startOfMonth(month);
            var today = new Date();
            var minYear = minDate ? minDate.getFullYear() : today.getFullYear() - 50;
            var maxYear = maxDate ? maxDate.getFullYear() + 1 : today.getFullYear() + 5;
            var dropdownMonths = Array.from({ length: 12 }, function (_, i) { return ({
                disabled: Boolean((minDate && isDayBefore(setMonth(month, i), minDate)) ||
                    (maxDate && isDayAfter(setMonth(month, i), maxDate))),
                value: i,
                selected: firstDay.getMonth() === i
            }); });
            var dropdownYears = Array.from({ length: maxYear - minYear }, function (_, i) { return ({
                value: i + minYear,
                disabled: false,
                selected: i + minYear === firstDay.getFullYear()
            }); });
            return [dropdownMonths, dropdownYears];
        };
        return _this;
    }
    CalendarMonth.prototype.getDaysofMonth = function (props) {
        var month = props.month, startDate = props.startDate, endDate = props.endDate, minDate = props.minDate, maxDate = props.maxDate;
        var currentMonth = getDatesofMonth(month);
        var startDateDisabled = !!startDate && !!minDate && !isDayAfter(startDate, minDate);
        return currentMonth.map(function (week) {
            return week.map(function (day) {
                var date = day.date, inCurrentMonth = day.inCurrentMonth;
                var disabled = !inCurrentMonth ||
                    Boolean((minDate && isDayBefore(date, minDate)) ||
                        (maxDate && isDayAfter(date, maxDate)));
                var selected = !disabled &&
                    Boolean((startDate && isSameDay(date, startDate)) ||
                        (endDate && isSameDay(date, endDate)));
                var inRange = Boolean(startDate &&
                    isDayAfter(date, startDate) &&
                    endDate &&
                    isDayBefore(date, endDate));
                return {
                    date: date,
                    inRange: inCurrentMonth &&
                        !startDateDisabled &&
                        !disabled && (selected || inRange),
                    selected: selected,
                    disabled: disabled,
                    inCurrentMonth: inCurrentMonth
                };
            });
        });
    };
    CalendarMonth.prototype.render = function () {
        var _a;
        var _b = this.props, month = _b.month, render = _b.render, showDropdowns = _b.showDropdowns;
        var monthsDropdown;
        var yearsDropdown;
        if (showDropdowns) {
            _a = this.getDropdowns(this.props), monthsDropdown = _a[0], yearsDropdown = _a[1];
        }
        return render({
            days: this.getDaysofMonth(this.props),
            month: startOfMonth(month),
            monthsDropdown: monthsDropdown,
            yearsDropdown: yearsDropdown
        });
    };
    return CalendarMonth;
}(React.Component));
export { CalendarMonth };
